<?php
/**
 * Plugin Name: dLocal Go payments for WooCommerce
 * Description: Accept local payment methods for LATAM using your dLocal Go Merchant account.
 * Version: 1.0.6
 * Author: dLocal Go
 * Author URI: https://dlocal.com/go/
 * Copyright: © 2021 WooCommerce / dLocal Go.
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: dlocal-go-payments-for-woocommerce
 * Domain Path: /languages
 * WC tested up to: 7.9.0
 * WC requires at least: 4.4
 */
/**
 * Copyright (c) 2021 dLocal Go.
 *
 * The name of the dLocal Go may not be used to endorse or promote products derived from this
 * software without specific prior written permission. THIS SOFTWARE IS PROVIDED ``AS IS'' AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

// Make sure WooCommerce is active
if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	return;
}

define( 'WC_GATEWAY_DLOCAL_GO_VERSION', '1.0.6' );

add_action( 'plugins_loaded', 'wc_gateway_dlocalgo_init', 0 );

/**
 * WC_Gateway_DlocalGo_Plugin init
 *
 * @return WC_Gateway_DlocalGo_Plugin
 */
function wc_gateway_dlocalgo_init() {
	static $plugin;

	// Localization
	load_plugin_textdomain( 'dlocal-go-payments-for-woocommerce', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );

	// Core class for dLocal Go Payment gateway
	if ( ! isset( $plugin ) ) {
		require_once( 'includes/class-wc-gateway-dlocalgo-plugin.php' );

		$plugin = new WC_Gateway_DlocalGo_Plugin( __FILE__, WC_GATEWAY_DLOCAL_GO_VERSION );
	}

	// Add the gateway to list of available gateways
	add_filter( 'woocommerce_payment_gateways', 'add_dlocalgo_payment_gateway' );

	// Add plugin action links
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wc_dlocalgo_gateway_plugin_links' );

	// HTTPS notice
	if ( (empty( $_SERVER['HTTPS'] ) || $_SERVER['HTTPS'] == 'off')) {
	    add_action( 'admin_notices', 'wc_dlocalgo_httpsNotice' );
	}

	return $plugin;
}

/**
 * Add the dLocal Go gateway to WC Available Gateways
 */
function add_dlocalgo_payment_gateway( $methods ) {
    $methods[] = 'WC_Gateway_DlocalGo_Plugin'; 
    return $methods;
}

/**
 * Adds plugin page links
 */
function wc_dlocalgo_gateway_plugin_links( $links ) {

	$plugin_links = array(
		'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=checkout&section=dlocal-go-payments-for-woocommerce' ) . '">' . __( 'Configure', 'dlocal-go-payments-for-woocommerce' ) . '</a>'
	);

	return array_merge( $plugin_links, $links );
}

/**
 *  HTTPS notice
 */
function wc_dlocalgo_httpsNotice()
{
    echo '<div class="notice notice-error">'. esc_html__( 'The store must have HTTPS to work with dLocal Go.', 'dlocal-go-payments-for-woocommerce' ) .'</div>';
}
